@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use base qw( Catalyst::Action );
 
-use NEXT;
+use MRO::Compat;
 use Carp qw( croak );
 
 sub execute {
@@ -13,7 +13,7 @@ sub execute {
 
     my $config = $controller->_html_formfu_config;
 
-    return $self->NEXT::execute(@_)
+    return $self->next::method(@_)
         unless exists $self->attributes->{ActionClass}
             && $self->attributes->{ActionClass}[0] eq
             $config->{multiform_method_action};
@@ -34,7 +34,7 @@ sub execute {
 
     $c->stash->{ $config->{multiform_stash} } = $multi;
 
-    $self->NEXT::execute(@_);
+    $self->next::method(@_);
 }
 
 1;
